@@ -24,6 +24,7 @@
 #' @import common
 #' @import xml2
 #' @import xslt
-#' @docType package
+#' @keywords internal
+#' @aliases defineR-package
 #' @name defineR
-NULL
+"_PACKAGE"
